@@ -1,6 +1,6 @@
 #! /usr/bin/env python
 # KNB Corpus reader
-# Copyright (C) 2001-2017 NLTK Project
+# Copyright (C) 2001-2018 NLTK Project
 # Author: Masato Hagiwara <hagisan@gmail.com>
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
@@ -9,8 +9,8 @@
 from __future__ import print_function
 
 import re
+from six import string_types
 
-from nltk.compat import string_types
 from nltk.parse import DependencyGraph
 
 from nltk.corpus.reader.util import (
