@@ -1,7 +1,7 @@
 # Natural Language Toolkit: Chat-80 KB Reader
 # See http://www.w3.org/TR/swbp-skos-core-guide/
 #
-# Copyright (C) 2001-2015 NLTK Project
+# Copyright (C) 2001-2018 NLTK Project
 # Author: Ewan Klein <ewan@inf.ed.ac.uk>,
 # URL: <http://nltk.sourceforge.net>
 # For license information, see LICENSE.TXT
@@ -129,8 +129,10 @@ import shelve
 import os
 import sys
 
+from six import string_types
+
 import nltk.data
-from nltk.compat import string_types, python_2_unicode_compatible
+from nltk.compat import python_2_unicode_compatible
 
 ###########################################################################
 # Chat-80 relation metadata bundles needed to build the valuation
@@ -503,9 +505,9 @@ def process_bundle(rels):
     dictionary of concepts, indexed by the relation name.
 
     :param rels: bundle of metadata needed for constructing a concept
-    :type rels: list of dict
+    :type rels: list(dict)
     :return: a dictionary of concepts, indexed by the relation name.
-    :rtype: dict
+    :rtype: dict(str): Concept
     """
     concepts = {}
     for rel in rels:
@@ -549,7 +551,8 @@ def make_valuation(concepts, read=False, lexicon=False):
         # add labels for individuals
         val = label_indivs(val, lexicon=lexicon)
         return val
-    else: return vals
+    else:
+        return vals
 
 
 def val_dump(rels, db):
@@ -561,7 +564,7 @@ def val_dump(rels, db):
     :type rels: list of dict
     :param db: name of file to which data is written.
                The suffix '.db' will be automatically appended.
-    :type db: string
+    :type db: str
     """
     concepts = process_bundle(rels).values()
     valuation = make_valuation(concepts, read=True)
@@ -578,7 +581,7 @@ def val_load(db):
 
     :param db: name of file from which data is read.
                The suffix '.db' should be omitted from the name.
-    :type db: string
+    :type db: str
     """
     dbname = db+".db"
 
@@ -640,8 +643,8 @@ def make_lex(symbols):
     create a lexical rule for the proper name 'Zloty'.
 
     :param symbols: a list of individual constants in the semantic representation
-    :type symbols: sequence
-    :rtype: list
+    :type symbols: sequence -- set(str)
+    :rtype: list(str)
     """
     lex = []
     header = """
@@ -671,9 +674,9 @@ def concepts(items = items):
     Build a list of concepts corresponding to the relation names in ``items``.
 
     :param items: names of the Chat-80 relations to extract
-    :type items: list of strings
+    :type items: list(str)
     :return: the ``Concept`` objects which are extracted from the relations
-    :rtype: list
+    :rtype: list(Concept)
     """
     if isinstance(items, string_types): items = (items,)
 
@@ -777,5 +780,3 @@ def sql_demo():
 if __name__ == '__main__':
     main()
     sql_demo()
-
-
