@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # Natural Language Toolkit: Twitter client
 #
-# Copyright (C) 2001-2016 NLTK Project
+# Copyright (C) 2001-2018 NLTK Project
 # Author: Lorenzo Rubio <lrnzcig@gmail.com>
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
@@ -16,9 +16,10 @@ import os
 from nltk.compat import TemporaryDirectory
 import unittest
 
+from six.moves import zip
+
 from nltk.corpus import twitter_samples
 from nltk.twitter.common import json2csv, json2csv_entities
-from nltk.compat import izip
 
 
 def are_files_identical(filename1, filename2, debug=False):
@@ -28,7 +29,7 @@ def are_files_identical(filename1, filename2, debug=False):
     with open(filename1, "rb") as fileA:
         with open(filename2, "rb") as fileB:
             result = True
-            for lineA, lineB in izip(sorted(fileA.readlines()),
+            for lineA, lineB in zip(sorted(fileA.readlines()),
                                      sorted(fileB.readlines())):
                 if lineA.strip() != lineB.strip():
                     if debug:
